Struct PersistentPool

pub struct PersistentPool<'a, C: ?Sized, T: RawAccess> { /* private fields */ }
Persistent transaction pool that uses both a provided ephemeral cache and the cache persisting in the node database.

Implementations

Source

impl<'a, C, T> PersistentPool<'a, C, T>

pub fn new<A>(access: A, cache: &'a C) -> Self
where A: Access<Base = T>,

Creates a new cache using the provided access to the storage and the ephemeral cache.