pub struct PersistentPool<'a, C: ?Sized, T: RawAccess> { /* private fields */ }Expand description
Persistent transaction pool that uses both a provided ephemeral cache and the cache persisting in the node database.
Implementations
Sourceimpl<'a, C, T> PersistentPool<'a, C, T>
impl<'a, C, T> PersistentPool<'a, C, T>