pub type InstanceId = u32;Expand description
Unique service instance identifier.
-
This is a secondary identifier, mainly used in transaction messages. The primary one is a service instance name.
-
The dispatcher assigns this identifier when the service is started.